---
title: '[릴리즈노트] 2024-08-07 업데이트'
category: 업데이트
tags:
  - 파트너정산
  - 업데이트
searchTags:
  - 지급 및 정산 내역의 다건 조회를 위한 API
  - 다건 조회
  - 업데이트
  - 릴리즈노트
datetime: 2024-11-05T05:35:58.442Z
---

<Callout title="2024년 08월 07일 파트너 정산 자동화 업데이트 소식을 안내드립니다." />



<Callout content="안녕하세요. 파트너 정산 자동화팀입니다.
24년 8월 7일, 서비스 업데이트 사항 안내드립니다.

지급 및 정산 내역의 다건 조회를 위한 API가 추가되었습니다." />

## **주요 업데이트 사항**

✔️ 지급/정산 내역 조회 API 지원



- 정산내역 다건 조회 API가 추가되었습니다.



- 지급 내역 다건 조회 API가 추가되었습니다.



- 일괄 지급 내역 다건 조회 API가 추가되었습니다.

✔️ 수기 정산 건 임의 정산일 지원

- 임의의 정산일을 지정해 수기 정산건을 등록할 수 있도록 변경되었습니다.
- 모든 정산일을 지원함에 따라 PlatformUnavailableSettlementDateError 에러가 삭제되었습니다.

##### [\[파트너정산 릴리즈노트\] 2024-08-07 업데이트 보러가기↗](https://developers.portone.io/release-notes/platform/2024-08-07)
